"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.websiteEndpoint = exports.route53 = exports.cloudfront = exports.acm = exports.iam = exports.lambda = exports.s3 = exports.bucketRegion = void 0;

var _awsSdk = require("aws-sdk");

// Bucket region must be fixed so that website endpoint is fixe
// https://docs.aws.amazon.com/fr_fr/general/latest/gr/rande.html#s3_website_region_endpoints
const bucketRegion = "eu-west-3";
exports.bucketRegion = bucketRegion;
const s3 = new _awsSdk.S3({
  apiVersion: "2006-03-01",
  region: bucketRegion
});
exports.s3 = s3;
const lambda = new _awsSdk.Lambda({
  region: "us-east-1"
});
exports.lambda = lambda;
const iam = new _awsSdk.IAM({
  region: "us-east-1",
  apiVersion: "2010-05-08"
}); // cloudfront certificates must be in us-east-1

exports.iam = iam;
const acm = new _awsSdk.ACM({
  region: "us-east-1"
});
exports.acm = acm;
const cloudfront = new _awsSdk.CloudFront();
exports.cloudfront = cloudfront;
const route53 = new _awsSdk.Route53(); // S3 API does not seem to expose this data
// https://docs.aws.amazon.com/fr_fr/general/latest/gr/rande.html#s3_website_region_endpoints

exports.route53 = route53;
const websiteEndpoint = {
  "us-east-2": "s3-website.us-east-2.amazonaws.com",
  "us-east-1": "s3-website-us-east-1.amazonaws.com",
  "us-west-1": "s3-website-us-west-1.amazonaws.com",
  "us-west-2": "s3-website-us-west-2.amazonaws.com",
  "ap-south-1": "s3-website.ap-south-1.amazonaws.com",
  "ap-northeast-3": "s3-website.ap-northeast-3.amazonaws.com",
  "ap-northeast-2": "s3-website.ap-northeast-2.amazonaws.com",
  "ap-southeast-1": "s3-website-ap-southeast-1.amazonaws.com",
  "ap-southeast-2": "s3-website-ap-southeast-2.amazonaws.com",
  "ap-northeast-1": "s3-website-ap-northeast-1.amazonaws.com",
  "ca-central-1": "s3-website.ca-central-1.amazonaws.com",
  "cn-northwest-1": "s3-website.cn-northwest-1.amazonaws.com.cn",
  "eu-central-1": "s3-website.eu-central-1.amazonaws.com",
  "eu-west-1": "s3-website-eu-west-1.amazonaws.com",
  "eu-west-2": "s3-website.eu-west-2.amazonaws.com",
  "eu-west-3": "s3-website.eu-west-3.amazonaws.com",
  "eu-north-1": "s3-website.eu-north-1.amazonaws.com",
  "sa-east-1": "s3-website-sa-east-1.amazonaws.com"
};
exports.websiteEndpoint = websiteEndpoint;